# Slot: values_from


identifies the possible uri's of the range

URI: [http://w3id.org/biolink/biolinkml/meta/values_from](slot_uri)
## Domain and Range

[Definition](Definition.md) -><sub>opt</sub> [[Uri](Uri.md)]
## Inheritance

## Children

## Used by

 * [ClassDefinition](ClassDefinition.md)
 * [Definition](Definition.md)
 * [SlotDefinition](SlotDefinition.md)
